// Copyright (C) 2004, 2005, 2006, 2007 Philip Aston
// All rights reserved.
//
// This file is part of The Grinder software distribution. Refer to
// the file LICENSE which is part of The Grinder distribution for
// licensing details. The Grinder distribution is available on the
// Internet at http://grinder.sourceforge.net/
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
// FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
// COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
// OF THE POSSIBILITY OF SUCH DAMAGE.

package net.grinder.common;


/**
 * Thread life cycle event call backs.
 *
 * <p>
 * All methods will be called using the thread to which the event refers.
 * </p>
 *
 * @author Philip Aston
 */
public interface ThreadLifeCycleListener {

  /**
   * This method is called just after the thread has started.
   *
   * <p>
   * Plugin thread listeners created by
   * {@link net.grinder.plugininterface.GrinderPlugin#createThreadListener} will
   * will receive this event, so long as their plugin registers itself before
   * the worker threads start (see notes at
   * {@link net.grinder.plugininterface.PluginRegistry}).
   * </p>
   */
  void beginThread();

  /**
   * This method is called at the start of every run.
   */
  void beginRun();

  /**
   * This method is called at the end of every run.
   */
  void endRun();

  /**
   * This method is called before the thread is shut down. This happens before
   * any <code>__del__</code> method is called.
   */
  void beginShutdown();

  /**
   * This method is called when the thread has been shut down.
   */
  void endThread();
}
